# This file was auto-generated by Fern from our API Definition.

import typing
from .z_3_expression import Z3Expression
from .structure_function_call import StructureFunctionCall
from .formalization_error import FormalizationError

Formalization = typing.Union[Z3Expression, StructureFunctionCall, FormalizationError]



# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .statement_feedback import StatementFeedback
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class StatementFeedbackDictionary(UniversalBaseModel):
    """
    A dictionary of statements with their ids by type.
    """

    cost_functions: typing.Optional[typing.List[StatementFeedback]] = pydantic.Field(default=None)
    """
    The validation feedback for cost functions.
    """

    structure_constraints: typing.Optional[typing.List[StatementFeedback]] = pydantic.Field(default=None)
    """
    The validation feedback for structure constraints.
    """

    parameter_constraints: typing.Optional[typing.List[StatementFeedback]] = pydantic.Field(default=None)
    """
    The validation feedback for parameter constraints.
    """

    query_summarizers: typing.Optional[typing.List[StatementFeedback]] = pydantic.Field(default=None)
    """
    The validation feedback for query summarizers.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .bundle import Bundle
from .bundle_settings_value import BundleSettingsValue
from .computation import Computation
from .computation_arguments_value import ComputationArgumentsValue
from .execute_code_response import ExecuteCodeResponse
from .extract_text_response import ExtractTextResponse
from .find_mapping_response import FindMappingResponse
from .formalization import Formalization
from .formalization_error import FormalizationError
from .formalize_circuit_response import FormalizeCircuitResponse
from .formalize_response import FormalizeResponse
from .generate_code_response import GenerateCodeResponse
from .generate_component_code_response import GenerateComponentCodeResponse
from .http_validation_error import HttpValidationError
from .interactive_response import InteractiveResponse
from .md_response import MdResponse
from .net import Net
from .netlist import Netlist
from .netlist_placements_value_value import NetlistPlacementsValueValue
from .optimization_history import OptimizationHistory
from .optimize_netlist_response import OptimizeNetlistResponse
from .parameter import Parameter
from .parse_response import ParseResponse
from .pdk_type import PdkType
from .pic_instance import PicInstance
from .pic_instance_info_value import PicInstanceInfoValue
from .pic_instance_settings_value import PicInstanceSettingsValue
from .refine_code_response import RefineCodeResponse
from .refine_component_code_response import RefineComponentCodeResponse
from .requirement_body import RequirementBody
from .solution_response import SolutionResponse
from .solution_response_solution_value import SolutionResponseSolutionValue
from .statement import Statement
from .statement_dictionary import StatementDictionary
from .statement_feedback import StatementFeedback
from .statement_feedback_dictionary import StatementFeedbackDictionary
from .statement_type import StatementType
from .structure_function_call import StructureFunctionCall
from .structure_function_call_arguments_value import StructureFunctionCallArgumentsValue
from .structure_function_call_expected_result import StructureFunctionCallExpectedResult
from .summarizer_response import SummarizerResponse
from .validate_netlist_response import ValidateNetlistResponse
from .validate_response import ValidateResponse
from .validation_error import ValidationError
from .validation_error_loc_item import ValidationErrorLocItem
from .verify_circuit_code_response import VerifyCircuitCodeResponse
from .verify_response import VerifyResponse
from .z_3_expression import Z3Expression

__all__ = [
    "Bundle",
    "BundleSettingsValue",
    "Computation",
    "ComputationArgumentsValue",
    "ExecuteCodeResponse",
    "ExtractTextResponse",
    "FindMappingResponse",
    "Formalization",
    "FormalizationError",
    "FormalizeCircuitResponse",
    "FormalizeResponse",
    "GenerateCodeResponse",
    "GenerateComponentCodeResponse",
    "HttpValidationError",
    "InteractiveResponse",
    "MdResponse",
    "Net",
    "Netlist",
    "NetlistPlacementsValueValue",
    "OptimizationHistory",
    "OptimizeNetlistResponse",
    "Parameter",
    "ParseResponse",
    "PdkType",
    "PicInstance",
    "PicInstanceInfoValue",
    "PicInstanceSettingsValue",
    "RefineCodeResponse",
    "RefineComponentCodeResponse",
    "RequirementBody",
    "SolutionResponse",
    "SolutionResponseSolutionValue",
    "Statement",
    "StatementDictionary",
    "StatementFeedback",
    "StatementFeedbackDictionary",
    "StatementType",
    "StructureFunctionCall",
    "StructureFunctionCallArgumentsValue",
    "StructureFunctionCallExpectedResult",
    "SummarizerResponse",
    "ValidateNetlistResponse",
    "ValidateResponse",
    "ValidationError",
    "ValidationErrorLocItem",
    "VerifyCircuitCodeResponse",
    "VerifyResponse",
    "Z3Expression",
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    Bundle,
    BundleSettingsValue,
    Computation,
    ComputationArgumentsValue,
    ExecuteCodeResponse,
    ExtractTextResponse,
    FindMappingResponse,
    Formalization,
    FormalizationError,
    FormalizeCircuitResponse,
    FormalizeResponse,
    GenerateCodeResponse,
    GenerateComponentCodeResponse,
    HttpValidationError,
    InteractiveResponse,
    MdResponse,
    Net,
    Netlist,
    NetlistPlacementsValueValue,
    OptimizationHistory,
    OptimizeNetlistResponse,
    Parameter,
    ParseResponse,
    PdkType,
    PicInstance,
    PicInstanceInfoValue,
    PicInstanceSettingsValue,
    RefineCodeResponse,
    RefineComponentCodeResponse,
    RequirementBody,
    SolutionResponse,
    SolutionResponseSolutionValue,
    Statement,
    StatementDictionary,
    StatementFeedback,
    StatementFeedbackDictionary,
    StatementType,
    StructureFunctionCall,
    StructureFunctionCallArgumentsValue,
    StructureFunctionCallExpectedResult,
    SummarizerResponse,
    ValidateNetlistResponse,
    ValidateResponse,
    ValidationError,
    ValidationErrorLocItem,
    VerifyCircuitCodeResponse,
    VerifyResponse,
    Z3Expression,
)
from .errors import UnprocessableEntityError
from . import code_execution, document, experimental, formalization, generic, lean, pic, requirements
from .client import AsyncAxiomatic, Axiomatic
from .environment import AxiomaticEnvironment
from .version import __version__

__all__ = [
    "AsyncAxiomatic",
    "Axiomatic",
    "AxiomaticEnvironment",
    "Bundle",
    "BundleSettingsValue",
    "Computation",
    "ComputationArgumentsValue",
    "ExecuteCodeResponse",
    "ExtractTextResponse",
    "FindMappingResponse",
    "Formalization",
    "FormalizationError",
    "FormalizeCircuitResponse",
    "FormalizeResponse",
    "GenerateCodeResponse",
    "GenerateComponentCodeResponse",
    "HttpValidationError",
    "InteractiveResponse",
    "MdResponse",
    "Net",
    "Netlist",
    "NetlistPlacementsValueValue",
    "OptimizationHistory",
    "OptimizeNetlistResponse",
    "Parameter",
    "ParseResponse",
    "PdkType",
    "PicInstance",
    "PicInstanceInfoValue",
    "PicInstanceSettingsValue",
    "RefineCodeResponse",
    "RefineComponentCodeResponse",
    "RequirementBody",
    "SolutionResponse",
    "SolutionResponseSolutionValue",
    "Statement",
    "StatementDictionary",
    "StatementFeedback",
    "StatementFeedbackDictionary",
    "StatementType",
    "StructureFunctionCall",
    "StructureFunctionCallArgumentsValue",
    "StructureFunctionCallExpectedResult",
    "SummarizerResponse",
    "UnprocessableEntityError",
    "ValidateNetlistResponse",
    "ValidateResponse",
    "ValidationError",
    "ValidationErrorLocItem",
    "VerifyCircuitCodeResponse",
    "VerifyResponse",
    "Z3Expression",
    "__version__",
    "code_execution",
    "document",
    "experimental",
    "formalization",
    "generic",
    "lean",
    "pic",
    "requirements",
]
